#pragma once

void renderAboutScreenFrame(void);
void initAboutScreen(void);
void showAboutScreen(void);
void hideAboutScreen(void);
void exitAboutScreen(void);
